package pdd

import (
	"duoduo/conf"
	"duoduo/models/pdd"
	"duoduo/tools"
	"duoduo/tools/app"
	"fmt"
	"github.com/gin-gonic/gin"
	"time"
)

func PddDdkGoodsPidQuery(c *gin.Context) {
	var inData pdd.PddDdkGoodsPidQueryRequest
	var outData pdd.PddDdkGoodsPidQueryResponse
	var pddErr pdd.ErrorPddResponse

	confIni, err := conf.ConnIni()
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	err = c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	inData.ClientId = confIni.MustValue("pdd", "client_id")
	inData.Type = "pdd.ddk.goods.pid.query"
	inData.Timestamp = fmt.Sprintf("%d", time.Now().Unix())
	inData.DataType = "JSON"
	inData.Sign = "sign"

	sign, err := DDKSign(inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	inData.Sign = sign
	val, err := PostDDk(inData, nil)

	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	err = tools.JsonUnmarshal(val, &pddErr)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	if pddErr.ErrorResponse.ErrorCode != 0 {
		app.Error(c, 500, err, pddErr.ErrorResponse.ErrorMsg)
		return
	}

	err = tools.JsonUnmarshal(val, &outData)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	app.OK(c, outData, app.Success)
}
